@@ -7,9 +7,9 @@
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 #
 
-from typing import Mapping, Optional, Any, Dict, Union
+from typing import Mapping, Any, Type
 
-from aiohttp import BasicAuth
+from aiohttp import BasicAuth, FormData
 from aiohttp.web_exceptions import HTTPServiceUnavailable
 from init_helpers.custom_json import Jsonable
 from multidict import CIMultiDict
@@ -22,32 +22,34 @@ class AbmServiceConnector:
     Config = HttpServerConnector.Config
     Context = HttpServerConnector.Context
 
-    def __init__(self, config: Config, context: Context) -> None:
-        self._connector = HttpServerConnector(config, context)
+    def __init__(
+            self, config: Config, context: Context, connector: Type[HttpServerConnector] = HttpServerConnector
+    ) -> None:
+        self._connector = connector(config, context)
 
     async def get(self,
                   path: str,
-                  url_query: Optional[Mapping[str, Any]] = None,
-                  headers: Optional[Mapping[str, str]] = None,
-                  auth: Optional[BasicAuth] = None,
-                  timeout_sec: Optional[float] = None) -> Any:
+                  url_query: Mapping[str, Any] | None = None,
+                  headers: Mapping[str, str] | None = None,
+                  auth: BasicAuth | None = None,
+                  timeout_sec: float | None = None) -> Any:
         headers = self._prepare_headers(headers)
         answer = await self._connector.get(path, url_query, headers, auth, timeout_sec)
         return self._parse_answer(answer)
 
     async def post(self,
                    path: str,
-                   payload: Union[bytes, Jsonable],
-                   url_query: Optional[Mapping[str, Any]] = None,
-                   headers: Optional[Mapping[str, str]] = None,
-                   auth: Optional[BasicAuth] = None,
-                   timeout_sec: Optional[float] = None) -> Any:
+                   payload: bytes | Jsonable | FormData,
+                   url_query: Mapping[str, Any] | None = None,
+                   headers: Mapping[str, str] | None = None,
+                   auth: BasicAuth | None = None,
+                   timeout_sec: float | None = None) -> Any:
         headers = self._prepare_headers(headers)
-        method = self._connector.post if isinstance(payload, bytes) else self._connector.post_json
+        method = self._connector.post if isinstance(payload, (bytes, FormData)) else self._connector.post_json
         answer = await method(path, payload, url_query, headers, auth, timeout_sec)
         return self._parse_answer(answer)
 
-    def _parse_answer(self, answer: Union[Dict[str, Any], bytes]) -> Any:
+    def _parse_answer(self, answer: dict[str, Any] | bytes) -> Any:
         if not isinstance(answer, dict):
             return answer
         try:
@@ -58,11 +60,9 @@ class AbmServiceConnector:
             raise HTTPServiceUnavailable(reason=f'Incorrect answer from {self._connector.config.url}: {answer}') from e
 
     @staticmethod
-    def _prepare_headers(required_headers: Optional[Mapping[str, str]]) -> CIMultiDict:
+    def _prepare_headers(required_headers: Mapping[str, str] | None) -> CIMultiDict:
         headers = CIMultiDict()
-        if required_headers:
-            for key, value in required_headers.items():
-                headers[key] = value
+        headers.update(required_headers or {})
         if request_id := CONTEXT_VAR_REQUEST_ID.get():
             headers[X_REQUEST_ID] = request_id
         return headers
