@@ -1,6 +1,7 @@
 import abc
 import dataclasses
 import logging
+import typing
 import urllib.parse
 from types import UnionType
 from typing import Any, Optional, Dict, Union
@@ -103,7 +104,7 @@ class StreamAnswer(BaseAnswer, aiohttp.web.StreamResponse):
             TypeError(f'Payload must be a str | bytes | None, got {type(payload)}'))
 
         if content_type is not None:
-            content_type_header_value = content_type + ('' if charset is not None else f'; charset={charset}')
+            content_type_header_value = content_type + ('' if charset is None else f'; charset={charset}')
             headers[aiohttp.hdrs.CONTENT_TYPE] = content_type_header_value
         aiohttp.web.StreamResponse.__init__(self, status=status_code, headers=headers)
         self.initial_data: bytes | None = payload
@@ -198,7 +199,7 @@ class JsonableAnswer(Answer):
             return getattr(cls, _FIXED_PAYLOAD_TYPE__NAME)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType]) -> type:
-        if isinstance(modifier, type | UnionType):
+        if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
             return create_type(_prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: modifier})
@@ -217,8 +218,7 @@ class WrappedAnswer(JsonableAnswer):
         return create_dataclass(_prepare_class_name([type_],  "Wrapped"), [cls], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
-        type_origin = getattr(modifier, '__origin__', None)
-        if type_origin or isinstance(modifier, type | UnionType):
+        if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
             wrapped_type = cls._wrap_type(modifier)
